@@ -1,4 +1,4 @@
-#$Id: Central.pm,v 1.2 2008/02/21 17:15:40 kawas Exp $
+#$Id: Central.pm,v 1.5 2008/05/14 14:04:03 kawas Exp $
 package MOBY::Client::Central;
 use SOAP::Lite;
 
@@ -80,14 +80,15 @@ BioMOBY Project:  http://www.biomoby.org
 
  ENV & PROXY : you can set environment variables to change the defaults.
              By default, a call to 'new' will initialize MOBY::Client::Central
-             to connect to the MOBY Central registry at:
-             http://mobycentral.cbr.nrc.ca/cgi-bin/MOBY05/mobycentral.pl
+             to connect to the default MOBY Central registry.  The location of
+             this registry can be determined by examining the redirect from:
+                http://biomoby.org/mobycentral
              If you wish to chose another registry by default, or if you need
              to set up additional connection details (e.g. PROXY) then you may
              set the following environment variables to whatever you
              require:
-             MOBY_SERVER  (default http://mobycentral.cbr.nrc.ca/cgi-bin/MOBY05/mobycentral.pl)
-             MOBY_URI     (default http://mobycentral.cbr.nrc.ca/MOBY/Central)
+             MOBY_SERVER  (default http://moby.ucalgary.ca/moby/MOBY-Central.pl)
+             MOBY_URI     (default http://moby.ucalgary.ca/MOBY/Central)
              MOBY_PROXY   (no default)
 
  Args      :    user_agent - optional.  The name of your software application
@@ -104,8 +105,8 @@ BioMOBY Project:  http://www.biomoby.org
                                 }
                             - by default this becomes
                             {mobycentral => {
-                                 URL => 'http://mobycentral.cbr.nrc.ca/cgi-bin/MOBY05/mobycentral.pl',
-                                 URI => 'http://mobycentral.cbr.nrc.ca/MOBY/Central'}
+                                 URL => 'http://moby.ucalgary.ca/moby/MOBY-Central.pl',
+                                 URI => 'http://moby.ucalgary.ca/MOBY/Central'}
                              }
  Discussion:    Each registry must have a different
                 NAME.  If you have more than one
@@ -639,7 +640,7 @@ sub deregisterNamespace {
      authURI      => $authURI,      
      contactEmail => "your@mail.address",      
      description => $human_readable_description, 
-     category  =>  "moby" | "post" | "moby-async"
+     category  =>  "moby" | "cgi" | "moby-async"
      URL    =>  $URL_TO_SERVICE  (or URL to WSDL document for wsdl-type services)
 
     input:	listref; (articleName may be undef) 
@@ -737,13 +738,13 @@ sub registerService {
 
 #____________________________________________________________________________________________
 	return $self->errorRegXML(
-"Only 'moby', 'post', 'moby-async', 'doc-literal', 'doc-literal-async' Service Categories are currently allowed - you gave me $Category"
+"Only 'moby', 'cgi', 'moby-async', 'doc-literal', 'doc-literal-async' Service Categories are currently allowed - you gave me $Category"
 	  )
 	  unless ( ( $Category eq 'moby' )
 			  || ( $Category eq 'moby-async' )
 			  || ( $Category eq 'doc-literal' )
 			  || ( $Category eq 'doc-literal-async' )
-			  || ( $Category eq 'post' ));
+			  || ( $Category eq 'cgi' ));
 	return $self->errorRegXML(
 "All Fields Required:  serviceName, serviceType, authURI, contactEmail, URL, description, Category, input, output, secondary"
 	  )
@@ -970,7 +971,7 @@ sub deregisterService {
      serviceType  => $serviceType,  (optional)
      authURI      => $authURI,      (optional)
      authoritative => 1,    (optional)
-     category  =>  "moby" | "post" | "moby-async"  (optional)
+     category  =>  "moby" | "cgi" | "moby-async"  (optional)
      expandObjects => 1,    (optional)
      expandServices => 1,    (optional)
      URL    =>  $URL_TO_SERVICE    (optional)
@@ -1923,10 +1924,16 @@ sub DUMP {
 	#	return $self->SOAP_connection($reg)->call('DUMP')->paramsall;
 	my ($SQLs) = $self->_call( $reg, 'DUMP_MySQL', "" );
 	my (
-		$mobycentral,   $mobyobject, $mobyservice,
-		$mobynamespace, $mobyrelationship
-	  )
-	  = @{$SQLs};
+            $mobycentral,   $mobyobject, $mobyservice,
+            $mobynamespace, $mobyrelationship
+        ) = @{$SQLs} unless ref($SQLs) eq 'HASH';
+
+		# cases where soap message is serialized as a HASH
+        (
+            $mobycentral,   $mobyobject, $mobyservice,
+            $mobynamespace, $mobyrelationship
+        ) = @{$SQLs->{item}} if ref($SQLs) eq 'HASH';
+        
 	return (
 		$mobycentral,   $mobyobject, $mobyservice,
 		$mobynamespace, $mobyrelationship
